### PART I ### DEFINING F:M COVERAGE LIMITS OF Z-SPECIFIC REGIONS IN S. MANSONI

##############################################################
## STEP1: Loci assignment based on 1% coverage of autosomes ##
##############################################################

## Set-up parameters
output="~/ZspecificRegion_Mansoni/Outputs_final/" ##Here indicate your outputfile name
spe="Smans" ##Here indicate the abbreviation of the studied species

## Read data
x=read.table("~/ZspecificRegion_Mansoni/Inputs_final/InputFile1_Smansoni_SoapCov_By10kb_ForR.txt",h=T) ##Here indicate your input table (5 columns modified SoapCoverage output)
head(x) #5columns: #Scaffold_ID #Window_start #Window_stop #MaleCoverage #FemaleCoverage
tail(x) #5columns
nrow(x) #36399rows==number of analysed windows out of SoapCoverage analysis

## Calculate Log2(F:Mcov)
x$log2_FMcoverage <- log2(x$ERR562990_Depth/x$ERR562989_Depth)
head(x) #6columns: 6th column=="log2_FMcoverage"

## Histogram - Overall genomic coverage distribution
hist(x$log2_FMcoverage, breaks=400, xlim=c(-2,2), ylim=c(0,5000), col="antiquewhite3", main="F:M coverage distribution - S. mansoni", xlab="log2 (F:M) ratio of coverage")

## Subset depending on the location 
x_Autosomes  <- subset(x, x$Scaffold_ID=='Chr_1' | x$Scaffold_ID=='Chr_2' | x$Scaffold_ID=='Chr_3' | x$Scaffold_ID=='Chr_4' |x$Scaffold_ID=='Chr_5' |x$Scaffold_ID=='Chr_6' |x$Scaffold_ID=='Chr_7')
head(x_Autosomes) #6columns
tail(x_Autosomes) #6columns
nrow(x_Autosomes) #19919rows
x_ZW  <- subset(x, x$Scaffold_ID=='Chr_ZW') ## Just to insure that the sum of nrow are correct
nrow(x_ZW)#5951
x_UP <- subset(x, x$Scaffold_ID!='Chr_1' & x$Scaffold_ID!='Chr_2' & x$Scaffold_ID!='Chr_3' & x$Scaffold_ID!='Chr_4' & x$Scaffold_ID!='Chr_5' & x$Scaffold_ID!='Chr_6' & x$Scaffold_ID!='Chr_7' & x$Scaffold_ID!='Chr_ZW')
nrow(x_UP) #10529 #19919Aut+5951ZW+10529UP=36399 initial rows

## Determining minCov_Aut & maxCov_Aut
maxCov_Aut <- quantile(x_Autosomes$log2_FMcoverage,0.95,na.rm=T)
maxCov_Aut #0.2296976
maxCov_Aut_Graph <- round(maxCov_Aut,digits = 4)
minCov_Aut  <- quantile(x_Autosomes$log2_FMcoverage,0.05,na.rm=T) #### Further used limit
minCov_Aut #-0.2626928
minCov_Aut_Graph <- round(minCov_Aut,digits = 4)

## Histogram - Autosomes
hist(x_Autosomes$log2_FMcoverage, breaks=400, xlim=c(-1,1), ylim=c(0,1200), col="gray37",border="gray50", main="F:M coverage distribution - Autosomes", xlab="log2 (F:M) ratio of coverage")
abline(v=maxCov_Aut,col="gray37",lwd=2,lty=2)
abline(v=minCov_Aut,col="sienna2",lwd=2,lty=2)
text(-0.3,1000,paste("5%min_Aut: ", minCov_Aut_Graph),srt=90,col="sienna2")
text(0.27,1000,paste("5%max_Aut: ", maxCov_Aut_Graph),srt=90,col="gray37")


###################################
## Vizualizing first step filter ##
###################################

## Parameters from first step
# maxCov_Aut==0.2296976 
# minCov_Aut==-0.2626928 

## Open table
#x <-read.table("~/ZspecificRegion_Mansoni/Inputs_final/InputFile1_Smansoni_SoapCov_By10kb_ForR.txt",fill=TRUE,header=TRUE)

## Log2(F:Mcov)
#x$log2_FMcoverage <- log2(x$ERR562990_Depth/x$ERR562989_Depth)

## Subset Chr_ZW
x_ZW  <- subset(x, x$Scaffold_ID=='Chr_ZW') 

## Define color
colFactor <- x_ZW$log2_FMcoverage
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(minCov_Aut))] <- "gray37" ; colF[which(colFactor<(minCov_Aut))] <- "sienna2"
colF

## Plot coverage ratio F:M
plot(as.numeric(paste(x_ZW$Window_start)), log2(as.numeric(paste(x_ZW$ERR562990_Depth))/as.numeric(paste(x_ZW$ERR562989_Depth))), col=colF, ylim=c(-2,2), pch=16, xlab='Position on the Z-chromosome', ylab='log2 (F:M) ratio of coverage', main="F:M coverage along S. mansoni Z-chromosome")
legend(x="bottomright",paste(c("5%min_Aut","PSA","Non-PSA")),pch=c(NA,16,16),lty=c(2,NA,NA),lwd=c(2,NA,NA),col=c("sienna2","gray37","sienna2"),bty="n")
abline(h=minCov_Aut, col="sienna2", lty=2, lw=2)


#################################
## Generating first step table ##
#################################

## Parameters from first step
maxCov_Aut=0.2296976 
minCov_Aut=-0.2626928 

## Define flags
Z <- which((x_ZW$log2_FMcoverage) < minCov_Aut)
PSA <- which((x_ZW$log2_FMcoverage) > minCov_Aut) 
flag <- rep("Ambiguous",nrow(x_ZW)) ; flag[Z] <- "Z" ; flag[PSA] <- "PSA"
x_ZW <- cbind(x_ZW,flag)
head(x_ZW)
tail(x_ZW)

#Write filtered final table with flags
coln=NULL ; for(j in 1:length(colnames(x_ZW))){coln <- c(coln,paste(colnames(x_ZW)[j],spe,sep="_"))}
write.table(x_ZW,paste(output,"InputFile2_Z_10kb_5pr100",".txt",sep=""),col.names=coln,row.names=F)


################################################################
## STEP2: Loci assignment based on 1% coverage of Zcandidates ##
################################################################

## Prepare table on excell with only the strict Z tags from the previous step (window +/- 1)

## Read data
x_Z=read.table("~/ZspecificRegion_Mansoni/Outputs_final/InputFile2_Smansoni_Z_10kb_5pr100.txt",h=T,fill=TRUE) #Input table with extracted putative Z-specific regions
head(x_Z) #7columns: 7th column=="flag_Smans" #It should be only "Z"
tail(x_Z) #7columns
nrow(x_Z) #2258

## Determining minCov_Aut & maxCov_Aut
maxCov_Z <- quantile(x_Z$log2_FMcoverage_Smans,0.99,na.rm=T)
maxCov_Z #-0.3956849 
maxCov_Z_Graph <- round(maxCov_Z,digits = 4)
minCov_Z  <- quantile(x_Z$log2_FMcoverage_Smans,0.01,na.rm=T) #### What's matter
minCov_Z #-1.102539
minCov_Z_Graph <- round(maxCov_Z,digits = 4)

## Histogram - Z chromosome
hist(x_Z$log2_FMcoverage_Smans, breaks=50, xlim=c(-2,0), ylim=c(0,150), col="sienna2", border="sienna1", main="F:M coverage distribution - Non-autosomes", xlab="log2 (F:M) ratio of coverage")
abline(v=maxCov_Z,col="gray37",lwd=2,lty=2)
abline(v=minCov_Z,col="sienna2",lwd=2,lty=2)
text(-1.15,100,paste("1%min_Z: ", minCov_Z_Graph),srt=90,col="sienna2")
text(-0.43,100,paste("1%max_Z: ", maxCov_Z_Graph),srt=90,col="gray37")


####################################
## Vizualizing second step filter ##
####################################

## Open table
x <-read.table("~/ZspecificRegion_Mansoni/Inputs_final/InputFile1_Smansoni_SoapCov_By10kb_ForR.txt",fill=TRUE,header=TRUE)
head(x) #5columns
tail(x) #5columns
nrow(x) #36399

## Log2(F:Mcov)
x$log2_FMcoverage <- log2(x$ERR562990_Depth/x$ERR562989_Depth)

## Subset Chr_ZW
x_ZW  <- subset(x, x$Scaffold_ID=='Chr_ZW') 
nrow(x_ZW) #5951

## Parameters from second step
maxCov_Z=-0.3956849  
minCov_Z=-1.102539 

## Coverage ratio F:M only on Z-linked windows
colFactor <- x_Z$log2_FMcoverage_Smans 
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "gray37" ; colF[which(colFactor<(maxCov_Z))] <- "sienna2"
plot(as.numeric(paste(x_Z$Window_start_Smans)), x_Z$log2_FMcoverage_Smans, col=colF, pch=16, ylim=c(-2,2), xlim=c(0,60000000),  xlab='Position on the Z-chromosome', ylab='log2(F:M) ratio of coverage', main="F:M genomic coverage distribution - Z linked windows")
abline(h=maxCov_Z, col="gray37",lwd=2,lty=2)
legend(x="bottomright",paste(c("5%max_Z","Non-Zlinked","Zlinked")),pch=c(NA,16,16),lty=c(2,NA,NA),lwd=c(2,NA,NA),col=c("gray37","gray37","sienna2"),bty="n")

## Plot coverage ratio F:M with ambiguous regions
colFactor <- x_ZW$log2_FMcoverage
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(minCov_Aut))] <- "gray37" ; colF[which(colFactor<(maxCov_Z))] <- "sienna2"
plot(as.numeric(paste(x_ZW$Window_start)), log2(as.numeric(paste(x_ZW$ERR562990_Depth))/as.numeric(paste(x_ZW$ERR562989_Depth))), col=colF,pch=16, ylim=c(-2,2), xlab='Position on the Z-chromosome', ylab='log2 (F:M) ratio of coverage', main="F:M genomic coverage distribution along S. mansoni Z-chromosome")
abline(h=minCov_Aut, col="gray37", lty=2, lwd=2)
abline(h=maxCov_Z, col="sienna2", lty=2, lwd=2)
legend(x="bottomright",paste(c("5%min_Aut","5%max_Z","Non-Zlinked","Zlinked")),pch=c(NA,NA,16,16),lty=c(2,2,NA,NA),lwd=c(2,2,NA,NA),col=c("gray37","sienna2","gray37","sienna2"),bty="n")

## Plot coverage ratio F:M without ambiguous regions #FIGURE 1
colFactor <- x_ZW$log2_FMcoverage
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "gray37" ; colF[which(colFactor<(maxCov_Z))] <- "sienna2"
plot(as.numeric(paste(x_ZW$Window_start)), log2(as.numeric(paste(x_ZW$ERR562990_Depth))/as.numeric(paste(x_ZW$ERR562989_Depth))), col=colF, pch=16, ylim=c(-1.8,1.25),xlim=c(0,61000000),adj="0.5", cex.axis=1.2, cex.lab=1.5, xlab='Position on S.mansoni Z-chromosome', ylab='log2(F:M)coverage')
abline(h=maxCov_Z, col="sienna2", lty=2, lwd=2)
legend(x="bottomright",paste(c("5%max_Z","Non-Zlinked","Zlinked")),pch=c(NA,16,16),lty=c(2,NA,NA),lwd=c(2,NA,NA),col=c("sienna2","gray37","sienna2"),bty="n")


### PART II ### APPLY F:M COVERAGE LIMITS OF Z-SPECIFIC REGIONS TO ALL S. MANSONI GENOME

## Set-up parameters
output1="~/ZspecificRegion_Mansoni/Outputs_final/Smansoni_byScaffold_Graphs/" # Indicate the output file for graphs
output2="~/ZspecificRegion_Mansoni/Outputs_final/Smansoni_byScaffold_Tables/" # Indicate the output file for tables
window="10kb" #Indicate the SoapCoverage genomic window used
maxCov_Z=-0.3956849 #Indicate the maximum limit of F:Mcoverage defined for Z-specific regions (see PART I)

## Open table
x <-read.table("~/ZspecificRegion_Mansoni/Inputs_final/InputFile1_Smansoni_SoapCov_By10kb_ForR.txt",fill=TRUE,header=TRUE)
head(x) #5columns
tail(x) #5columns
nrow(x) #36399

## Log2(F:Mcov)
x$log2_FMcoverage <- log2(x$ERR562990_Depth/x$ERR562989_Depth)

## Select chromosome or scaffold

## Systematic attribution of Autosomal, Z-linked or ambiguous assignment: Plots
for (i in unique(x$Scaffold_ID))  {
  x_i <- subset(x, x$Scaffold_ID==i)

Z_i <- which((x_i$log2_FMcoverage) < maxCov_Z)
Autosomal_i <- which((x_i$log2_FMcoverage) > maxCov_Z) 
flag <- rep("Ambiguous",nrow(x_i)) ; flag[Z_i] <- "Z" ; flag[Autosomal_i] <- "Autosome"
x_i <- cbind(x_i,flag)

pdf(file=paste(output1,i,"_",window,".pdf",sep=""),w=15,h=10)

colFactor <- x_i$log2_FMcoverage 
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "gray37" ; colF[which(colFactor<(maxCov_Z))] <- "sienna1"

plot(as.numeric(paste(x_i$Window_start)), x_i$log2_FMcoverage, col=colF, pch=16, ylim=c(-2,2), xlab='Position on the scaffold', ylab='log2 (F:M) ratio of coverage', main=paste('Genomic coverage distribution along ',i))
abline(h=maxCov_Z, col="sienna2", lty=2,lwd=2)
legend(x="bottomright",paste(c("5%max_Z","Autosomes/PSA","Z-linked")),pch=c(NA,16,16),lty=c(2,NA,NA),lwd=c(2,NA,NA),col=c("sienna2","gray37","sienna2"),bty="n")

graphics.off()
}

## Systematic attribution of Autosomal, Z-linked or ambiguous assignment: Tables
for (i in unique(x$Scaffold_ID))  {
  x_i <- subset(x, x$Scaffold_ID==i)
  
Z_i <- which((x_i$log2_FMcoverage) < maxCov_Z)
Autosomal_i <- which((x_i$log2_FMcoverage) > maxCov_Z) 
flag <- rep("Ambiguous",nrow(x_i)) ; flag[Z_i] <- "Z" ; flag[Autosomal_i] <- "Autosome"
x_i <- cbind(x_i,flag)
  
  
# Write filtered final table with flags
coln=NULL ; for(j in 1:length(colnames(x_i))){coln <- c(coln,paste(colnames(x_i)[j],sep="_"))}
write.table(x_i,file=paste(output2,i,"Zspe",length(Z),"_PSA",length(PSA),".txt",sep=""),col.names=coln,row.names=F)
  
}
