### PART I ### DEFINING F:M COVERAGE LIMITS OF Z-SPECIFIC REGIONS IN S. JAPONICUM

# Infos: library40640==male, library40641==female

## Open data table
CovData <-read.table("~/ZspecificRegion_japonicum/Inputs_final/InputFile3_Sjaponicum_SoapCov_Bestloc_ForR",fill=TRUE,header=TRUE) #Open modified table constructed from Bestlocation and SoapCov outputs
head(CovData) #9columns: #SmansoniGeneID #SmansoniGeneLocation #SmansoniGeneFirstBase #SmansoniGeneLenght #SjaponicumScaffoldID #SjaponicumScaffoldLength #SjaponicumScaffoldMaleCoverage #SjaponicumScaffoldFemaleCoverage
tail(CovData) #9columns
nrow(CovData) #8564

## Filter on minimum coverage=1
CovData <- subset(CovData, CovData$Depth_40640>1 & CovData$Depth_40641>1)
head(CovData) #9columns
nrow(CovData) #8540

## Calculate log2(F:M ratio of coverage)
CovData$log2FMcov <- log2(CovData$Depth_40641/CovData$Depth_40640)
head(CovData) #10 columns: 10th colum=="log2FMcov"

# Subset depending on best location
CovData_1 <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_1')
head(CovData_1)
nrow(CovData_1) #1548
CovData_2 <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_2')
head(CovData_2)
nrow(CovData_2) #840
CovData_3 <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_3')
head(CovData_3)
nrow(CovData_3) #723
CovData_4 <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_4')
head(CovData_4)
nrow(CovData_4) #725
CovData_5 <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_5')
head(CovData_5)
nrow(CovData_5) #197
CovData_6 <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_6')
head(CovData_6)
nrow(CovData_6) #478
CovData_7 <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_7')
head(CovData_7)
nrow(CovData_7) #186
CovData_PSA <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_PSA')
head(CovData_PSA)
nrow(CovData_PSA) #863
CovData_Z <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_Z')
head(CovData_Z)
nrow(CovData_Z) #606
CovData_newZ <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_newZ')
head(CovData_newZ)
nrow(CovData_newZ) #199

CovData_UP <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_UP')
head(CovData_UP)
nrow(CovData_UP) #2171

CovData_Zlinked <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_newZ'| CovData$Scaffold_Bestloc_jap=='Chr_Z')
head(CovData_Zlinked)
nrow(CovData_Zlinked) #805
CovData_Aut <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_1' | CovData$Scaffold_Bestloc_jap=='Chr_2' | CovData$Scaffold_Bestloc_jap=='Chr_3' | CovData$Scaffold_Bestloc_jap=='Chr_4' | CovData$Scaffold_Bestloc_jap=='Chr_5' |CovData$Scaffold_Bestloc_jap=='Chr_6' |CovData$Scaffold_Bestloc_jap=='Chr_7')
head(CovData_Aut)
nrow(CovData_Aut) #4697

###################
## General plots ##
###################

# Coverage distribution
hist(CovData$log2FMcov,breaks=200, main = 'F:M coverage distribution - S. japonicum', ylim=c(0,2700), xlim=c(-2,1), xlab='Log2Cov', col='antiquewhite2')
hist(CovData$Depth_40641,breaks=1000, main = 'S. japonicum female genomic coverage', xlim=c(0,60), xlab='Log2Cov', col='deeppink3')
hist(CovData$Depth_40640,breaks=1000, main = 'S. japonicum male genomic coverage', ylim=c(0,2000), xlim=c(0,60), xlab='Log2Cov', col='royalblue3')

# Boxplot per S. mansoni chromosomes ### ABLINE TO SHOW RELEVANCE OF THE Z-SPECIFIC MAX TRESHOLD
boxplot(CovData_1$log2FMcov,CovData_2$log2FMcov,CovData_3$log2FMcov,CovData_4$log2FMcov,CovData_5$log2FMcov,CovData_6$log2FMcov,CovData_7$log2FMcov,CovData_PSA$log2FMcov,CovData_Z$log2FMcov,CovData_newZ$log2FMcov,CovData_UP$log2FMcov, names = c("1","2","3","4","5","6","7","PSA","Z","newZ","UP"), notch=T, outline = T, col=c("gray37","gray37","gray37","gray37","gray37","gray37","gray37","gray37","sienna1","sienna1","antiquewhite2"),ylim=c(-2,1), main='S. japonicum (Female:Male) coverage depending on chromosome assignment', xlab='S. mansoni chromosomes', ylab='Log2Cov')
boxplot(CovData_Aut$log2FMcov,CovData_Zlinked$log2FMcov, names = c("Autosomes","Zlinked"), notch=T, outline = T, col=c("gray37","sienna1"),ylim=c(-2,1),main='S. japonicum F:M genomic coverage ratio depending on chromosome allocation', xlab='S. mansoni chromosomes', ylab='Log2Cov')

abline(h=minCov_Aut) # See later how minCov_Aut is determined (STEP1)
abline(h=maxCov_Z) # See later how minCov_Aut is determined (STEP2)


#################
## Along the Z ##
#################

# Select sex-chromosomes linked scaffolds
CovData_sex <- subset(CovData, CovData$Scaffold_Bestloc_jap=='Chr_PSA' |  CovData$Scaffold_Bestloc_jap=='Chr_Z') 
head(CovData_sex)
CovData_sex <- subset(CovData_sex, CovData_sex$Gene_location_mans =='Chr_PSA' | CovData_sex$Gene_location_mans =='Chr_Z') ## Necessary here to exclude the into-the-z gene movment: S. mansoni autosomal genes can not be placed along the Z
head(CovData_sex)
tail(CovData_sex)
nrow(CovData_sex) #1301

# Select Z-spe and PSA scaffolds
CovData_Zspe <- subset(CovData_sex , CovData_sex$Scaffold_Bestloc_jap == 'Chr_Z')
nrow(CovData_Zspe) #554
CovData_PSA <- subset(CovData_sex , CovData_sex$Scaffold_Bestloc_jap == 'Chr_PSA')
nrow(CovData_PSA) #747

# Define colors
colFactor <- as.factor(CovData_sex$Gene_location_mans)
colFactor
colFactor1 <- levels(colFactor)[9]
colFactor1
colFactor2 <- levels(colFactor)[11]
colFactor2
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor==colFactor1)] <- "gray37" ; colF[which(colFactor==colFactor2)] <- "sienna1"
colF

## Plot coverage
head(CovData_sex) #10 columns
plot(as.numeric(paste(CovData_sex$First_Base)), as.numeric(paste(CovData_sex$log2FMcov)), pch=16, col=colF, ylim=c(-1.8,1.25), ylab="log2(F:M)coverage",xlim=c(0,61000000),adj="0.5", cex.axis=1.2, cex.lab=1.5, xlab="Position on S.mansoni Z-chromosome", main="F:M coverage along S. mansoni Z-chromosome")


####Medians for plot
CovData_PSA$FMratio  <- CovData_PSA$Depth_40641/CovData_PSA$Depth_40640
median_plotdata <- median(as.numeric(paste(CovData_PSA$FMratio)))
median_plotdata
abline(h=log2(median_plotdata), col="Gray37",lwd=2,l=2)

CovData_Zspe$FMratio  <-CovData_Zspe$Depth_40641/CovData_Zspe$Depth_40640
median_plotdata_Zspe <- median(as.numeric(paste(CovData_Zspe$FMratio )))
median_plotdata_Zspe
abline(h=log2(median_plotdata_Zspe), col="sienna1",lwd=2,l=2)

#########################################################
## Assignment of the position of S. japonicum scaffold ##
#########################################################

#######
#STEP1#
#######

#Set-up parameters here:
output="~/ZspecificRegion_japonicum/OutputFinal/"
outg="Smans"
spe="Sjap"

# Open the data table
x <-read.table("~/ZspecificRegion_japonicum/Inputs_final/InputFile3_Sjaponicum_SoapCov_Bestloc_ForR",fill=TRUE,header=TRUE)
head(x)
tail(x)
nrow(x) #8564

# Filter on minimum coverage=1
x <- subset(x, x$Depth_40640>1 & x$Depth_40641>1)
head(x) #9columns
nrow(x) #8540

# log2(F:M ratio of coverage)
x$FMratio <- x$Depth_40641/x$Depth_40640
x$log2FMcov <- log2(x$FMratio)
head(x) #11columns

# Subset autosomes depending on bestlocation
x_Aut <- subset(x, x$Scaffold_Bestloc_jap=='Chr_1' | x$Scaffold_Bestloc_jap=='Chr_2' | x$Scaffold_Bestloc_jap=='Chr_3' | x$Scaffold_Bestloc_jap=='Chr_4' | x$Scaffold_Bestloc_jap=='Chr_5' | x$Scaffold_Bestloc_jap=='Chr_6' | x$Scaffold_Bestloc_jap=='Chr_7')
head(x_Aut)
nrow(x_Aut) #4697

# Plot coverage autosome : determination of maxCov_Aut & minCov_Aut
hist(x_Aut$log2FMcov, breaks=400, col='gray37', main="F:M coverage distribution - Autosomes", xlim=c(-1,1),ylim=c(0,1500), xlab="Log2Cov")

maxCov_Aut <- quantile(x_Aut$log2FMcov,0.99,na.rm=T)
maxCov_Aut #0.1256426
maxCov_Aut_Graph <- round(maxCov_Aut,digits = 4)
minCov_Aut  <- quantile(x_Aut$log2FMcov,0.01,na.rm=T) #### What's matter
minCov_Aut #-0.3985494 
minCov_Aut_Graph <- round(minCov_Aut,digits = 4)

abline(v=maxCov_Aut,col="gray37",lwd=2,lty=2)
abline(v=minCov_Aut,col="sienna2",lwd=2,lty=2)
text(-0.45,1200,paste("minCov_Aut:  ", minCov_Aut_Graph),srt=90,col="sienna2")
text(0.08,1200,paste("maxCov_Aut:  ", maxCov_Aut_Graph),srt=90,col="gray37")

# Plot coverage Z : determination of maxCov_Z & minCov_Z
## Select sex-chromosomes linked scaffolds
x_sex <- subset(x, x$Scaffold_Bestloc_jap=='Chr_PSA' |  x$Scaffold_Bestloc_jap=='Chr_Z') 
head(x_sex)
x_sex <- subset(x_sex, x_sex$Gene_location_mans =='Chr_PSA' | x_sex$Gene_location_mans =='Chr_Z') ## Necessary here to exclude the into-the-z gene movment: S. mansoni autosomal genes can not be placed along the Z
head(x_sex)
tail(x_sex)
nrow(x_sex) #1301

## Select Z-spe and PSA scaffolds
x_Zspe <- subset(x_sex , x_sex$Scaffold_Bestloc_jap == 'Chr_Z')
nrow(x_Zspe) #554
x_PSA <- subset(x_sex , x_sex$Scaffold_Bestloc_jap == 'Chr_PSA')
nrow(x_PSA) #747

## Plot along the Z 
colFactor <- x_sex$log2FMcov
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(minCov_Aut))] <- "gray37" ; colF[which(colFactor<(minCov_Aut))] <- "sienna1"
plot(as.numeric(paste(x_sex$First_Base)), as.numeric(paste(x_sex$log2FMcov)), col=colF, pch=16, ylim=c(-2,1),ylab="log2(F:M ratio of coverage)", xlab="S. mansoni Z-chromosome", main="F:M coverage along S. mansoni Z-chromosome")
abline(h=minCov_Aut)
legend(x="bottomright",paste(c("Non-Aut","Aut")),pch=c(16,16),col=c("sienna1","gray37"))

#Assign loci Z-linked based on 5% coverage of autosomes
Non_Aut <- which((x_sex$log2FMcov) < minCov_Aut)
Aut <- which((x_sex$log2FMcov) > minCov_Aut) 
flag <- rep("Ambiguous",nrow(x_sex)) ; flag[Non_Aut] <- "Non_Aut" ; flag[Aut] <- "Aut"
x_sex <- cbind(x_sex,flag)
head(x_sex)
tail(x_sex)

#Write filtered final table with flags
coln=NULL ; for(j in 1:length(colnames(x_sex))){coln <- c(coln,paste(colnames(x_sex)[j],spe,sep="_"))}
write.table(x_sex,paste(output,spe,"_FinalTable_Loci_METHOD2_step1_1prcent",".txt",sep=""),append=F,quote=F,sep='\t',col.names=coln,row.names=F)


#######
#STEP2#
#######

# Select the data table subset resulting from step1
x_strictZ <- read.table("~/ZspecificRegion_japonicum/Inputs_final/InputFile4_Sjaponicum_1pr100",header=T)
head(x_strictZ)

# Filter on minimum coverage=1
x_strictZ  <- subset(x_strictZ, x_strictZ$Depth_40640>1 & x_strictZ$Depth_40641>1)
head(x_strictZ)
nrow(x_strictZ)

# log2(F:M ratio of coverage)
x_strictZ$FMratio <- x_strictZ$Depth_40641/x_strictZ$Depth_40640
x_strictZ$log2FMcov <- log2(x_strictZ$FMratio)
head(x_strictZ)

## Coverage distribution of stict Z linked scaffolds after the first step
hist(as.numeric(paste(x_strictZ$log2FMcov)), breaks=40, col="sienna1", xlim=c(-2,0), ylim=c(0,200), main="F:M coverage distribution - Non-autosomes", xlab="log2(covF)")

maxCov_Z <- quantile(x_strictZ$log2FMcov,0.95,na.rm=T) #### What's matter
maxCov_Z
maxCov_Z_Graph <- round(maxCov_Z,digits = 4)
minCov_Z <- quantile(x_strictZ$log2FMcov,0.05,na.rm=T)
minCov_Z
minCov_Z_Graph <- round(minCov_Z,digits = 4)

abline(v=maxCov_Z,col="gray37",lwd=2,lty=2)
abline(v=minCov_Z,col="sienna2",lwd=2,lty=2)
text(-1.35,150,paste("minCov_Z:  ", minCov_Z_Graph),srt=90,col="sienna2")
text(-0.75,150,paste("maxCov_Z:  ", maxCov_Z_Graph),srt=90,col="gray37")

## Define color
colFactor <- x_strictZ$log2FMcov 
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "gray37" ; colF[which(colFactor<(maxCov_Z))] <- "sienna1"
colF

## Plot coverage 
head(x_strictZ)
plot(as.numeric(paste(x_strictZ$First_Base)), as.numeric(paste(x_strictZ$log2FMcov)), pch=16,col=colF, ylim=c(-2,1), ylab="log2(F:M cov ratio)", xlab="S. mansoni Z-chromosome", main="Assigment of S. japonicum scaffolds position (step2)")
abline(h=maxCov_Z, col="gray37",lwd=2, l=2)
legend(x="bottomright",paste(c("MaxCov_Z","Non-Zspe","Zspe")),pch=c(15,16,16),col=c("gray37","gray37","sienna1"))

#################
## Test METHOD ##
#################

#Set-up parameters here:
output="~/ZspecificRegion_japonicum/Outputs_final/"
outg="Smans"
spe="Sjap"
maxCov_Z=-0.8403815 ### Changedepending on result step2
minCov_Aut=-0.3985494   ### Changedepending on result step1
  
# Prepare big table
x <-read.table("~/ZspecificRegion_japonicum/Inputs_final/InputFile3_Sjaponicum_SoapCov_Bestloc_ForR",fill=TRUE,header=TRUE)
x <- subset(x, x$Depth_40640>1 & x$Depth_40641>1)
x$FMratio <- x$Depth_40641/x$Depth_40640
x$log2FMcov <- log2(x$FMratio)
head(x)

# Select sex-chromosomes linked scaffolds
x_sex <- subset(x, x$Scaffold_Bestloc_jap=='Chr_PSA' |  x$Scaffold_Bestloc_jap=='Chr_Z') 
head(x_sex)
x_sex <- subset(x_sex, x_sex$Gene_location_mans =='Chr_PSA' | x_sex$Gene_location_mans =='Chr_Z') ## Necessary here to exclude the into-the-z gene movment: S. mansoni autosomal genes can not be placed along the Z
head(x_sex)
tail(x_sex)
nrow(x_sex)

# Select Z-spe and PSA scaffolds
x_Zspe <- subset(x_sex , x_sex$Scaffold_Bestloc_jap == 'Chr_Z')
nrow(x_Zspe)
x_PSA <- subset(x_sex , x_sex$Scaffold_Bestloc_jap == 'Chr_PSA')
nrow(x_PSA)

# Plot colors only considering maxCov_Z
colFactor <- x_sex$log2FMcov
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "gray37" ; colF[which(colFactor<(maxCov_Z))] <- "sienna1"
colF

# Plot colors considering both maxCov_Z and minCov_Aut
colFactor <- x_sex$log2FMcov
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "antiquewhite2" ; colF[which(colFactor>(minCov_Aut))] <- "gray37"; colF[which(colFactor<(maxCov_Z))] <- "sienna1"
colF

## Plot coverage
head(x_sex)
x_sex <- subset(x_sex,x_sex$First_Base!="n.a.")
plot(as.numeric(paste(x_sex$First_Base)), as.numeric(paste(x_sex$log2FMcov)), pch=16, col=colF, ylim=c(-2,1), ylab="log2(F:M ratio of coverage)", xlab="S. mansoni Z-chromosome", main="Assigment of S. japonicum scaffolds position")
abline(h=minCov_Aut, col="antiquewhite2",lwd=2,l=2)
abline(h=maxCov_Z, col="sienna1",lwd=2,l=2)
#legend(x="bottomright",paste(c("MaxCov_Z","PSA","Zspe")),pch=c(15,16,16),col=c("sienna1","gray37","sienna1")) # To choose depending on color factor
legend(x="bottomright",paste(c("MinCov_Aut","MaxCov_Z","PSA","Ambiguous","Zspe")),pch=c(NA,NA, 16,16,16),lty=c(2,2,NA,NA,NA),col=c("antiquewhite2","sienna1","gray37","antiquewhite2","sienna1"))

## Plot coverage for FIGURE 1
colFactor <- x_sex$log2FMcov
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "antiquewhite2" ; colF[which(colFactor>(minCov_Aut))] <- "gray37"; colF[which(colFactor<(maxCov_Z))] <- "sienna1"
plot(as.numeric(paste(x_sex$First_Base)), as.numeric(paste(x_sex$log2FMcov)), pch=16, col=colF, ylim=c(-1.8,1.25), ylab="log2(F:M)coverage",xlim=c(0,61000000),adj="0.5", cex.axis=1.2, cex.lab=1.5, xlab="Position on S.mansoni Z-chromosome")


### PART II ### APPLY F:M COVERAGE LIMITS OF Z-SPECIFIC REGIONS TO ALL S. JAPONICUM GENOME

# Define parameter
maxCov_Z=-0.8403815 ### Changedepending on result step2
minCov_Aut=-0.3985494   ### Changedepending on result step1
output="~/ZspecificRegion_Japonicum/OutputFinal/"
outg="Smans"
spe="Sjap"

# Prepare big table
x <-read.table("~/ZspecificRegion_japonicum/Inputs_final/InputFile3_Sjaponicum_SoapCov_Bestloc_ForR",fill=TRUE,header=TRUE) # For scaffolds with S. mansoni synteny
x <-read.table("~/ZspecificRegion_japonicum/Inputs_final/InputFile3-2_Sjaponicum_SoapCov_ForR",fill=TRUE,header=TRUE) # For all S. japonicum genome
x <- subset(x, x$Depth_40640>1 & x$Depth_40641>1)
x$FMratio <- x$Depth_40641/x$Depth_40640
x$log2FMcov <- log2(x$FMratio)
head(x)

# Define flags
Z <- which((x$log2FMcov) < maxCov_Z)
PSA <- which((x$log2FMcov) > minCov_Aut) 
flag <- rep("Ambiguous",nrow(x)) ; flag[Z] <- "Z" ; flag[PSA] <- "Autosome"
x <- cbind(x,flag)
head(x)
tail(x)

#Write filtered final table with flags
coln=NULL ; for(j in 1:length(colnames(x))){coln <- c(coln,paste(colnames(x)[j],spe,sep="_"))}
write.table(x,paste(output,"/",spe,"_FinalTable_Loci_METHOD2_FINAL_withAmbiguous",".txt",sep=""),append=F,quote=F,sep='\t',col.names=coln,row.names=F)

