### PART I ### DEFINING F:M COVERAGE LIMITS OF Z-SPECIFIC REGIONS IN S. HAEMATOBIUM

# Open data table
CovData <-read.table("~/ZspecificRegion_haematobium/Inputs_final/InputFile5_Shaematobium_SoapCov_Bestloc_ForR.txt",fill=TRUE,header=TRUE)
head(CovData)
tail(CovData)
nrow(CovData) #9437

# Filter on minimum coverage=1
CovData <- subset(CovData, CovData$Depth_ERR037800>1 & CovData$Depth_ERR036251>1)
head(CovData)
nrow(CovData)

# log2(Fcoverage)
CovData$log2Fcov <- log2(CovData$Depth_ERR037800+CovData$Depth_ERR036251)
head(CovData)

# Subset depending on best location
CovData_1 <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_1')
head(CovData_1)
nrow(CovData_1) #1760
CovData_2 <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_2')
head(CovData_2)
nrow(CovData_2) #918
CovData_3 <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_3')
head(CovData_3)
nrow(CovData_3) #771
CovData_4 <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_4')
head(CovData_4)
nrow(CovData_4) #798
CovData_5 <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_5')
head(CovData_5)
nrow(CovData_5) #226
CovData_6 <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_6')
head(CovData_6)
nrow(CovData_6) #537
CovData_7 <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_7')
head(CovData_7)
nrow(CovData_7) #184
CovData_PSA <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_PSA')
head(CovData_PSA)
nrow(CovData_PSA) #913
CovData_Z <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_Z')
head(CovData_Z)
nrow(CovData_Z) #718
CovData_newZ <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_newZ')
head(CovData_newZ)
nrow(CovData_newZ) #222
# Unplaced
CovData_UP <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_UP')
head(CovData_UP)
nrow(CovData_UP) #2335
# More global subsets
CovData_Zlinked <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_newZ'| CovData$Scaffold_Bestloc_haem=='Chr_Z')
head(CovData_Zlinked)
nrow(CovData_Zlinked) #940
CovData_Aut <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_1' | CovData$Scaffold_Bestloc_haem=='Chr_2' | CovData$Scaffold_Bestloc_haem=='Chr_3' | CovData$Scaffold_Bestloc_haem=='Chr_4' | CovData$Scaffold_Bestloc_haem=='Chr_5' |CovData$Scaffold_Bestloc_haem=='Chr_6' |CovData$Scaffold_Bestloc_haem=='Chr_7')
head(CovData_Aut)
nrow(CovData_Aut) #5194

###################
## General plots ##
###################

# Coverage distribution
hist(CovData$log2Fcov,breaks=200, main = 'S. haematobium female genomic coverage',ylim=c(0,1700),freq=T, xlim=c(2,7), xlab='Log2Cov', col='Deeppink3')

# Boxplot per S. mansoni chromosomes ### ABLINE TO SHOW RELEVANCE OF THE Z-SPECIFIC MAX TRESHOLD
boxplot(CovData_1$log2Fcov,CovData_2$log2Fcov,CovData_3$log2Fcov,CovData_4$log2Fcov,CovData_5$log2Fcov,CovData_6$log2Fcov,CovData_7$log2Fcov,CovData_PSA$log2Fcov,CovData_Z$log2Fcov,CovData_newZ$log2Fcov,CovData_UP$log2Fcov, names = c("1","2","3","4","5","6","7","PSA","Z","newZ","UP"), notch=T, outline = T, col=c("gray37","gray37","gray37","gray37","gray37","gray37","gray37","gray37","sienna1","sienna1","antiquewhite2"),ylim=c(3,6.5), main='Female coverage depending on chromosome assignment', xlab='S. mansoni chromosomes', ylab='Log2Cov')
boxplot(CovData_Aut$log2Fcov,CovData_Zlinked$log2Fcov, names = c("Autosomes","Zlinked"), notch=T, outline = T, col=c("gray37","sienna1"),ylim=c(3.5,6.5),main='S. haematobium female genomic coverage depending on chromosome allocation', xlab='S. mansoni chromosomes', ylab='Log2Cov')
abline(h=minCov_Aut) # See later how minCov_Aut is determined (STEP1)
abline(h=maxCov_Z) # See later how minCov_Aut is determined (STEP2)

#################
## Along the Z ##
#################

# Select sex-chromosomes linked scaffolds
CovData_sex <- subset(CovData, CovData$Scaffold_Bestloc_haem=='Chr_PSA' |  CovData$Scaffold_Bestloc_haem=='Chr_Z') 
head(CovData_sex)
CovData_sex <- subset(CovData_sex, CovData_sex$Gene_location_mans =='Chr_PSA' | CovData_sex$Gene_location_mans =='Chr_Z') ## Necessary here to exclude the into-the-z gene movment: S. mansoni autosomal genes can not be placed along the Z
head(CovData_sex)
tail(CovData_sex)
nrow(CovData_sex) #1496

# Select Z-spe and PSA scaffolds
CovData_Zspe <- subset(CovData_sex , CovData_sex$Scaffold_Bestloc_haem == 'Chr_Z')
nrow(CovData_Zspe) #649
CovData_PSA <- subset(CovData_sex , CovData_sex$Scaffold_Bestloc_haem == 'Chr_PSA')
nrow(CovData_PSA) #847

# Plot colors
colFactor <- as.factor(CovData_sex$Gene_location_mans)
colFactor
colFactor1 <- levels(colFactor)[9]
colFactor1
colFactor2 <- levels(colFactor)[11]
colFactor2
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor==colFactor1)] <- "gray37" ; colF[which(colFactor==colFactor2)] <- "sienna1"
colF

## Plot coverage

###Females
head(CovData_sex)
CovData_sex <- subset(CovData_sex,CovData_sex$First_Base_mans!="n.a.")
plot(as.numeric(paste(CovData_sex$First_Base_mans)), as.numeric(paste(CovData_sex$log2Fcov)), pch=16, col=colF, ylim=c(3.6,5.6),xlim=c(0,61000000),adj="0.5", cex.axis=1.2, cex.lab=1.5, ylab="log2(Female coverage)", xlab="Position on S. mansoni Z-chromosome")


####Medians for female plot
CovData_Aut$femalesum <- CovData_Aut$Depth_ERR037800+CovData_Aut$Depth_ERR036251
median_plotdata <- median(as.numeric(paste(CovData_Aut$femalesum)))
median_plotdata
abline(h=log2(median_plotdata), col="Gray37",lwd=2)

CovData_PSA$femalesum <- CovData_PSA$Depth_ERR037800+CovData_PSA$Depth_ERR036251
median_plotdata <- median(as.numeric(paste(CovData_PSA$femalesum)))
median_plotdata
abline(h=log2(median_plotdata), col="Gray37",lwd=2,l=2)

CovData_Zspe$femalesum <- CovData_Zspe$Depth_ERR037800+CovData_Zspe$Depth_ERR036251
median_plotdata_Zspe <- median(as.numeric(paste(CovData_Zspe$femalesum)))
median_plotdata_Zspe
abline(h=log2(median_plotdata_Zspe), col="sienna1",lwd=2,l=2)

######################################################################
## Assignment of the position of S. haematobium scaffold : METHOD 2 ##
######################################################################

#######
#STEP1#
#######

#Set-up parameters here:
output="~/ZspecificRegion_haematobium/Outputs_final/"
outg="Smans"
spe="Shaem"

# Open the data table
x <-read.table("~/ZspecificRegion_haematobium/Inputs_final/InputFile5_Shaematobium_SoapCov_Bestloc_ForR.txt",fill=TRUE,header=TRUE)
head(x)
tail(x)
nrow(x)

# Filter on minimum coverage=1
CovData <- subset(CovData, CovData$Depth_ERR037800>1 & CovData$Depth_ERR036251>1)
head(CovData)
nrow(CovData)

# Female coverage
x$femalesum <- x$Depth_ERR037800+x$Depth_ERR036251
x$log2Fcov <- log2(x$femalesum)

# Subset autosomes
x_Aut <- subset(x, x$Scaffold_Bestloc_haem=='Chr_1' | x$Scaffold_Bestloc_haem=='Chr_2' | x$Scaffold_Bestloc_haem=='Chr_3' | x$Scaffold_Bestloc_haem=='Chr_4' | x$Scaffold_Bestloc_haem=='Chr_5' | x$Scaffold_Bestloc_haem=='Chr_6' | x$Scaffold_Bestloc_haem=='Chr_7')
head(x_Aut)
nrow(x_Aut)

# Plot coverage autosome : determination of maxCov_Aut & minCov_Aut
hist(x_Aut$log2Fcov, breaks=200, col='Gray37', main="Female coverage - Autosomes", xlim=c(3,6),ylim=c(0,1200), xlab="Log2Cov")

maxCov_Aut <- quantile(x_Aut$log2Fcov,0.95,na.rm=T)
maxCov_Aut 
maxCov_Aut_Graph <- round(maxCov_Aut,digits = 4)
minCov_Aut  <- quantile(x_Aut$log2Fcov,0.05,na.rm=T) #### What's matter
minCov_Aut
minCov_Aut_Graph <- round(minCov_Aut,digits = 4)

abline(v=maxCov_Aut,col="gray37",lwd=2,lty=2)
abline(v=minCov_Aut,col="sienna2",lwd=2,lty=2)
text(4.5,1000,paste("minCov_Aut:  ", minCov_Aut_Graph),srt=90,col="sienna2")
text(5.25,1000,paste("maxCov_Aut:  ", maxCov_Aut_Graph),srt=90,col="gray37")


# Plot coverage Z : determination of maxCov_Z & minCov_Z
## Select sex-chromosomes linked scaffolds
x_sex <- subset(x, x$Scaffold_Bestloc_haem=='Chr_PSA' |  x$Scaffold_Bestloc_haem=='Chr_Z') 
head(x_sex)
x_sex <- subset(x_sex, x_sex$Gene_location_mans =='Chr_PSA' | x_sex$Gene_location_mans =='Chr_Z') ## Necessary here to exclude the into-the-z gene movment: S. mansoni autosomal genes can not be placed along the Z
head(x_sex)
tail(x_sex)
nrow(x_sex)

## Select Z-spe and PSA scaffolds
x_Zspe <- subset(x_sex , x_sex$Scaffold_Bestloc_haem == 'Chr_Z')
nrow(x_Zspe)
x_PSA <- subset(x_sex , x_sex$Scaffold_Bestloc_haem == 'Chr_PSA')
nrow(x_PSA)

## Plot along the Z 
colFactor <- x_sex$log2Fcov
colFactor 
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(minCov_Aut))] <- "gray37" ; colF[which(colFactor<(minCov_Aut))] <- "sienna1"
colF
plot(as.numeric(paste(x_sex$First_Base_mans)), as.numeric(paste(x_sex$log2Fcov)), col=colF, ylim=c(3,6),ylab="log2(Female coverage)", xlab="S. mansoni Z-chromosome", main="Female coverage along S. mansoni Z-chromosome")
abline(h=minCov_Aut)
legend(x="bottomright",paste(c("Non-Aut","Aut")),pch=c(16,16),col=c("sienna1","gray37"))

#Assign loci Z-linked based on 5% coverage of autosomes
minCov_Aut

Z <- which((x_sex$log2Fcov) < minCov_Aut)
PSA <- which((x_sex$log2Fcov) > minCov_Aut) 
flag <- rep("Ambiguous",nrow(x_sex)) ; flag[Z] <- "Z" ; flag[PSA] <- "PSA"
x_sex <- cbind(x_sex,flag)
head(x_sex)
tail(x_sex)

#Write filtered final table with flags
coln=NULL ; for(j in 1:length(colnames(x_sex))){coln <- c(coln,paste(colnames(x_sex)[j],spe,sep="_"))}
write.table(x_sex,paste(output,"/",spe,"_FinalTable_Loci_METHOD2_step1",".txt",sep=""),append=F,quote=F,sep='\t',col.names=coln,row.names=F)


#######
#STEP2#
#######

# Select the data table subset resulting from step1
x_strictZ <- read.table("~/ZspecificRegion_haematobium/Inputs_final/InputFile6_Shaematobium_5pr100.txt",header=T)
head(x_strictZ)

## Coverage distribution of stict Z linked scaffolds after the first step
hist(as.numeric(paste(x_strictZ$log2Fcov_Shaem)), breaks=30, col="sienna1", xlim=c(3,5), ylim=c(0,200), main="F:M coverage distribution - Non-autosomes", xlab="log2(covF)")

maxCov_Z <- quantile(x_strictZ$log2Fcov_Shaem,0.95,na.rm=T) #### What's matter
maxCov_Z
maxCov_Z_Graph <- round(maxCov_Z,digits = 4)
minCov_Z <- quantile(x_strictZ$log2Fcov_Shaem,0.05,na.rm=T)
minCov_Z
minCov_Z_Graph <- round(minCov_Z,digits = 4)

abline(v=maxCov_Z,col="gray37",lwd=2,lty=2)
abline(v=minCov_Z,col="sienna2",lwd=2,lty=2)
text(3.8,150,paste("minCov_Z:  ", minCov_Z_Graph),srt=90,col="sienna2")
text(4.5,150,paste("maxCov_Z:  ", maxCov_Z_Graph),srt=90,col="gray37")

## Define color
colFactor <- x_strictZ$log2Fcov_Shaem 
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "gray37" ; colF[which(colFactor<(maxCov_Z))] <- "sienna1"
colF

## Plot coverage 
head(x_strictZ)
plot(as.numeric(paste(x_strictZ$First_Base_mans_Shaem)), x_strictZ$log2Fcov_Shaem, col=colF, ylim=c(3,5),ylab="log2(Female coverage)", xlab="S. mansoni Z-chromosome", main="Assigment of S. haematobium scaffolds position - Method 2 (step2)")
abline(h=maxCov_Z, col="gray37")
legend(x="bottomright",paste(c("MaxCov_Z","Zspe","Non-Zspe")),pch=c(15,16,16),col=c("gray37","gray37","sienna1"))

###################
## Test METHOD 2 ##
###################

#Set-up parameters here:
output="~/ZspecificRegion_haematobium/Outputs_final/"
outg="Smans"
spe="Shaem"
maxCov_Z=4.405992 ### Changedepending on result step2
minCov_Aut=4.574704 ### Changedepending on result step1
  
# Open table
x <-read.table("~/ZspecificRegion_haematobium/Inputs_final/InputFile5_Shaematobium_SoapCov_Bestloc_ForR.txt",fill=TRUE,header=TRUE)
head(x)
tail(x)
nrow(x)

# Filter on minimum coverage=1
x <- subset(x, x$Depth_ERR037800>1 & x$Depth_ERR036251>1)
head(x)
nrow(x)

# log2(Fcoverage)
x$log2Fcov <- log2(x$Depth_ERR037800+x$Depth_ERR036251)
head(x)

# Select sex-chromosomes linked scaffolds
x_sex <- subset(x, x$Scaffold_Bestloc_haem=='Chr_PSA' |  x$Scaffold_Bestloc_haem=='Chr_Z') 
head(x_sex)
x_sex <- subset(x_sex, x_sex$Gene_location_mans =='Chr_PSA' | x_sex$Gene_location_mans =='Chr_Z') ## Necessary here to exclude the into-the-z gene movment: S. mansoni autosomal genes can not be placed along the Z
head(x_sex)
tail(x_sex)
nrow(x_sex)

# Select Z-spe and PSA scaffolds
x_Zspe <- subset(x_sex , x_sex$Scaffold_Bestloc_haem == 'Chr_Z')
nrow(x_Zspe)
x_PSA <- subset(x_sex , x_sex$Scaffold_Bestloc_haem == 'Chr_PSA')
nrow(x_PSA)

# Plot colors only considering maxCov_Z
colFactor <- x_sex$log2Fcov
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "gray37" ; colF[which(colFactor<(maxCov_Z))] <- "sienna1"
colF

# Plot colors considering both maxCov_Z and minCov_Aut
colFactor <- x_sex$log2Fcov
colF <- rep("antiquewhite2",length(colFactor)) ; colF[which(colFactor>(maxCov_Z))] <- "antiquewhite2" ; colF[which(colFactor>(minCov_Aut))] <- "gray37"; colF[which(colFactor<(maxCov_Z))] <- "sienna1"
colF

## Plot coverage for FIGURE 1
head(x_sex)
x_sex <- subset(x_sex,x_sex$First_Base_mans!="n.a.")
#x_sex$femalesum <- x_sex$Depth_ERR037800+x_sex$Depth_ERR036251
#x_sex$log2Fcov <- log2(x_sex$femalesum)
plot(as.numeric(paste(x_sex$First_Base_mans)), as.numeric(paste(x_sex$log2Fcov)), pch=16, col=colF, ylim=c(3,6), ylab="log2(Female coverage)", xlab="S. mansoni Z-chromosome", main="Assigment of S. haematobium scaffolds position")
abline(h=minCov_Aut, col="antiquewhite2",lwd=2,l=2)
abline(h=maxCov_Z, col="sienna1",lwd=2,l=2)
legend(x="bottomright",paste(c("MinCov_Aut","MaxCov_Z","PSA","Ambiguous","Zspe")),pch=c(NA,NA, 16,16,16),lty=c(2,2, NA,NA,NA),col=c("antiquewhite2","sienna1","gray37","antiquewhite2","sienna1"))


### PART II ### APPLY F:M COVERAGE LIMITS OF Z-SPECIFIC REGIONS TO ALL S. HAEMATOBIUM GENOME

# Define parameter
maxCov_Z=4.405992 ### Change depending on result step2
minCov_Aut=4.574704 ### Change depending on result step1

# Prepare big table
x <-read.table("~/ZspecificRegion_haematobium/Inputs_final/InputFile5_Shaematobium_SoapCov_Bestloc_ForR.txt",fill=TRUE,header=TRUE) # For scaffolds with S. mansoni synteny
x <-read.table("~/ZspecificRegion_haematobium/Inputs_final/InputFile5-2_Shaematobium_SoapCov_ForR.txt",fill=TRUE,header=TRUE) # For all S. haematobium genome
x <- subset(x, x$Depth_ERR037800>1 & x$Depth_ERR036251>1)
x$log2Fcov <- log2(x$Depth_ERR037800+x$Depth_ERR036251)
head(x)

# Define flags
Z <- which((x$log2Fcov) < maxCov_Z)
PSA <- which((x$log2Fcov) > minCov_Aut) 
flag <- rep("Ambiguous",nrow(x)) ; flag[Z] <- "Z" ; flag[PSA] <- "Autosome"
x <- cbind(x,flag)
head(x)
tail(x)

#Write filtered final table with flags
coln=NULL ; for(j in 1:length(colnames(x))){coln <- c(coln,paste(colnames(x)[j],spe,sep="_"))}
write.table(x,paste(output,"/",spe,"_FinalTable_Loci_METHOD2_FINAL_withAmbiguous",".txt",sep=""),append=F,quote=F,sep='\t',col.names=coln,row.names=F)


